@@ -2,9 +2,11 @@ mod memory_storage;
 mod sled_storage;
 mod ws_server;
 mod ws_client;
+mod ws_conn;
 mod multicast;
 pub use memory_storage::MemoryStorage;
 pub use sled_storage::SledStorage;
 pub use multicast::Multicast;
 pub use ws_server::WsServer;
+pub use ws_conn::WsConn;
 pub use ws_client::OutgoingWebsocketManager;
\ No newline at end of file
